@@ -2,6 +2,7 @@ import os
 import time
 from multiprocessing import Queue
 from multiprocessing import Process
+from queue import Empty
 
 from mpscreen.components import buffer, bufferServer, line, lineServer, Vstr, Vint, SR, SL
 
@@ -16,7 +17,10 @@ def _screenMainLoop(s):
             s.getTerminalSize()
             resizeCheck = int(round(time.time() * 1000))
             s.refresh(f=True)
-        msg = s.q.get()
+        try:
+            msg = s.q.get(timeout=0.5)
+        except Empty:
+            s.refresh()
 
         if msg[0] == 'Q':
             return
@@ -85,21 +89,21 @@ class server:
 def linePrinter(cs: line):
     for i in range(50, 300):
         cs["v"].set("xxx" + str(i) * 3)
-        time.sleep(0.2)
+        time.sleep(2.2)
 
 
 def linePrinter2(cs: line):
     cs.total = 200
     for i in range(0, 2000):
         cs["count"].add(1)
-        time.sleep(0.2)
+        time.sleep(1.2)
 
 
 def bufferPrinter(bs: buffer):
     for i in range(1000, 3000):
         bs.append(('\u001b[48;5;13m') + (str(i) * (2)))
         bs.append((str(i) * 13))
-        time.sleep(0.1)
+        time.sleep(1.1)
 
 
 
